Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(386)

Unified Diff: src/heap/heap.h

Issue 1034163002: Use atomic operation to read the length of a fixed array. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/factory.cc ('k') | src/heap/heap.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/heap/heap.h
diff --git a/src/heap/heap.h b/src/heap/heap.h
index 8e4952e8a83fb5e2d577a42f50eef38af99c16e9..5067344fc00e8b7c71af3741b006116159f92b3a 100644
--- a/src/heap/heap.h
+++ b/src/heap/heap.h
@@ -741,9 +741,11 @@ class Heap {
bool CanMoveObjectStart(HeapObject* object);
- // Indicates whether live bytes adjustment is triggered from within the GC
- // code or from mutator code.
- enum InvocationMode { FROM_GC, FROM_MUTATOR };
+ // Indicates whether live bytes adjustment is triggered
+ // - from within the GC code before sweeping started (SWEEPING_IS_OFF),
+ // - or from within GC (SWEEPING_STARTED),
+ // - or mutator code (SWEEPING_STARTED).
+ enum InvocationMode { SWEEPING_IS_OFF, SWEEPING_STARTED };
Hannes Payer (out of office) 2015/03/26 16:27:24 Can we call it SEQUENTIAL_TO_SWEEPER and CONCURREN
// Maintain consistency of live bytes during incremental marking.
void AdjustLiveBytes(Address address, int by, InvocationMode mode);
« no previous file with comments | « src/factory.cc ('k') | src/heap/heap.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698